import { bold } from "kleur/colors";
function getHandlerFromModule(mod, method) {
  if (mod[method]) {
    return mod[method];
  }
  if (mod["ALL"]) {
    return mod["ALL"];
  }
  return void 0;
}
async function renderEndpoint(mod, context, ssr, logger) {
  const { request, url } = context;
  const chosenMethod = request.method?.toUpperCase();
  const handler = getHandlerFromModule(mod, chosenMethod);
  if (!ssr && ssr === false && chosenMethod && chosenMethod !== "GET") {
    logger.warn(
      null,
      `${url.pathname} ${bold(
        chosenMethod
      )} requests are not available for a static site. Update your config to \`output: 'server'\` or \`output: 'hybrid'\` to enable.`
    );
  }
  if (!handler || typeof handler !== "function") {
    let response = new Response(null, {
      status: 404,
      headers: {
        "X-Astro-Response": "Not-Found"
      }
    });
    return response;
  }
  const proxy = new Proxy(context, {
    get(target, prop) {
      if (prop in target) {
        return Reflect.get(target, prop);
      } else {
        return void 0;
      }
    }
  });
  return handler.call(mod, proxy, request);
}
export {
  renderEndpoint
};
